@@ -1,7 +1,7 @@
 context("selection-freqs")
 
 test_that("selection-freqs",{
-
+library(parsnip)
 
   rf_no_forest <- randomForest::randomForest(iris[,-5], factor(iris$Species), ntree = 100, keep.forest = FALSE)
   set.seed(1234)
@@ -11,10 +11,20 @@ test_that("selection-freqs",{
   set.seed(1234)
   ranger_w_forest <- ranger::ranger(factor(iris$Species) ~., iris[,-5], write.forest = TRUE, num.trees = 100)
 
+  model_parsnip_ranger <-
+    rand_forest(mode = 'classification') %>% set_engine("ranger", importance = 'impurity') %>%
+    fit(Species ~ ., iris)
+
+  model_parsnip_rf <-
+    rand_forest(mode = 'classification') %>% set_engine("randomForest") %>%
+    fit(Species ~ ., iris)
 
   expect_true(is.data.frame(selection_freqs(rf_w_forest)))
   expect_true(is.data.frame(selection_freqs(ranger_w_forest)))
 
+  expect_true(is.data.frame(selection_freqs(model_parsnip_ranger)))
+  expect_true(is.data.frame(selection_freqs(model_parsnip_rf)))
+
   expect_error(selection_freqs(rf_no_forest))
   expect_error(selection_freqs(ranger_no_forest))
 
